@@ -539,10 +539,14 @@ def dbus_path(p):
 
 def _get_click_dir_variable():
     '''Format click databases as variable'''
-    # snappy hardcodes these and doing this allows snappy images to not require
-    # click
-    if os.path.exists("/usr/bin/snappy"):
-        return "{%s}" % ",".join(["/apps", "/oem"])
+    # snappy hardcodes the click databases and if we can detect if a snappy
+    # system then we can hardcode them too and not require click.
+    # /usr/share/doc/ubuntu-snappy is shipped by ubuntu-snappy which is only
+    # available on snappy systems. This is fairly brittle but click-apparmor
+    # functionality is moving into snappy itself, so this is ok for now
+    if os.path.exists("/usr/bin/snappy") and \
+            os.path.isdir("/usr/share/doc/ubuntu-snappy"):
+        return "{%s}" % ",".join(["/apps", "/oem", "/frameworks"])
 
     from gi.repository import Click
 
@@ -637,8 +641,9 @@ def _ubuntu_transform(click_manifest, policy_version):
                 newp.policyversion = float(profile['policy_version'])
             else:
                 raise AppArmorExceptionClickInvalidPolicyVersion(
-                    "Invalid policy version '%s' " % profile['policy_version']
-                    + "for framework '%s'" % click_manifest.framework)
+                    "Invalid policy version '%s' " %
+                    profile['policy_version'] +
+                    "for framework '%s'" % click_manifest.framework)
 
         newp.add_variable("APP_PKGNAME", click_manifest.app_pkgname)
         newp.add_variable("APP_APPNAME", click_manifest.app_appname)
@@ -853,9 +858,12 @@ framework_transforms = {
     "ubuntu-sdk-14.04": (_ubuntu_transform, 1.1),
     "ubuntu-sdk-14.10": (_ubuntu_transform, 1.2),
     "ubuntu-sdk-15.04": (_ubuntu_transform, 1.3),
+    "ubuntu-sdk-15.10": (_ubuntu_transform, 15.10),
     "ubuntu-core-15.04": (_ubuntu_transform, 15.04),
     "ubuntu-core-15.10": (_ubuntu_transform, 15.10),
     "ubuntu-core-16.04": (_ubuntu_transform, 16.04),
+    "ubuntu-personal-15.10": (_ubuntu_transform, 15.10),
+    "ubuntu-personal-16.04": (_ubuntu_transform, 16.04),
 }
 
 # Define where framework policy files live
